package org.eclipse.graphiti.examples.diagram;

import org.eclipse.emf.ecore.EClass;
import org.eclipse.graphiti.features.IAddFeature;
import org.eclipse.graphiti.features.IFeatureProvider;
import org.eclipse.graphiti.features.context.IAddContext;
import org.eclipse.graphiti.features.impl.AbstractAddFeature;
import org.eclipse.graphiti.mm.algorithms.Polygon;
import org.eclipse.graphiti.mm.algorithms.Rectangle;
import org.eclipse.graphiti.mm.pictograms.ContainerShape;
import org.eclipse.graphiti.mm.pictograms.Diagram;
import org.eclipse.graphiti.mm.pictograms.PictogramElement;
import org.eclipse.graphiti.services.Graphiti;
import org.eclipse.graphiti.services.IGaService;
import org.eclipse.graphiti.services.IPeCreateService;
import org.eclipse.graphiti.util.IColorConstant;

public class AddEClassFeature extends AbstractAddFeature implements IAddFeature {

	public AddEClassFeature(IFeatureProvider fp) {
		super(fp);
	}

	@Override
	public boolean canAdd(IAddContext context) {
		return context.getNewObject() instanceof EClass
				&& context.getTargetContainer() instanceof Diagram;
	}

	@Override
	public PictogramElement add(IAddContext context) {
		EClass addedClass = (EClass) context.getNewObject();
		Diagram targetDiagram = (Diagram) context.getTargetContainer();
		IPeCreateService peCreateService = Graphiti.getPeCreateService();
		IGaService gaService = Graphiti.getGaService();

		ContainerShape containerShape = peCreateService.createContainerShape(
				targetDiagram, true);

		Polygon invisiblePolygon = gaService.createPolygon(containerShape,
				new int[] { 25, 0, 100, 0, 70, 60, 0, 60 });
		invisiblePolygon.setFilled(false);
		invisiblePolygon.setLineVisible(false);
		gaService.setLocationAndSize(invisiblePolygon, context.getX(),
				context.getY(), context.getWidth(), context.getHeight());

		Polygon polygon = gaService.createPolygon(invisiblePolygon, new int[] {
				25, 0, 100, 0, 75, 50, 0, 50 });
		gaService.setLocation(polygon, 0, 0);
		polygon.setFilled(false);

		Polygon polygon2 = gaService.createPolygon(invisiblePolygon, new int[] {
				50, 50, 55, 55, 50, 60, 45, 55 });
		gaService.setLocation(polygon2, 0, 0);
		polygon2.setFilled(true);
		polygon2.setBackground(manageColor(IColorConstant.LIGHT_GREEN));

		peCreateService.createChopboxAnchor(containerShape);

		link(containerShape, addedClass);

		return containerShape;
	}

}
